@@ -2,21 +2,21 @@
 module Debian.Control.PrettyPrint where
 
 import qualified Data.ByteString.Char8 as C
-import Text.PrettyPrint.HughesPJ
+import Text.PrettyPrint.ANSI.Leijen
 
 import Debian.Control.Common
 
 ppControl :: (ToText a) => Control' a -> Doc
 ppControl (Control paragraph) =
-    fsep (map ppParagraph paragraph)
+    vcat (map ppParagraph paragraph)
 
 ppParagraph :: (ToText a) => Paragraph' a -> Doc
 ppParagraph (Paragraph fields) =
-    fsep (map ppField fields)
+    vcat (map ppField fields ++ [empty])
 
 ppField :: (ToText a) => Field' a -> Doc
 ppField (Field (n,v)) = totext n <> text ":" <> totext v
-
+ppField (Comment c) = totext c
 
 class ToText a where
     totext :: a -> Doc
